DateTimeRangeQuery

Struct DateTimeRangeQuery 

pub struct DateTimeRangeQuery { /* private fields */ }
Specialized datetime range query for optimal performance.

Implementations

Source

impl DateTimeRangeQuery

pub fn new<S: Into<String>>( field: S, lower: Option<DateTime<Utc>>, upper: Option<DateTime<Utc>>, lower_inclusive: bool, upper_inclusive: bool, ) -> Self

Create a new datetime range query.

pub fn between<S: Into<String>>( field: S, start: DateTime<Utc>, end: DateTime<Utc>, ) -> Self

Create a datetime range with both bounds inclusive.

pub fn after<S: Into<String>>(field: S, datetime: DateTime<Utc>) -> Self

Create a query for dates after the given datetime.

pub fn on_or_after<S: Into<String>>(field: S, datetime: DateTime<Utc>) -> Self

Create a query for dates on or after the given datetime.

pub fn before<S: Into<String>>(field: S, datetime: DateTime<Utc>) -> Self

Create a query for dates before the given datetime.

pub fn on_or_before<S: Into<String>>(field: S, datetime: DateTime<Utc>) -> Self

Create a query for dates on or before the given datetime.

pub fn with_boost(self, boost: f32) -> Self

Set the boost factor for this query.

pub fn field(&self) -> &str

Get the field name.

pub fn contains_timestamp(&self, timestamp: i64) -> bool

Check if a timestamp falls within the range.

pub fn contains_datetime(&self, datetime: &DateTime<Utc>) -> bool

Check if a datetime falls within the range.