pub struct SuggestionEngine { /* private fields */ }Expand description
Main spelling suggestion engine.
Implementations
Sourceimpl SuggestionEngine
impl SuggestionEngine
Sourcepub fn new(dictionary: SpellingDictionary) -> Self
pub fn new(dictionary: SpellingDictionary) -> Self
Create a new suggestion engine with the given dictionary.
Sourcepub fn with_config(
dictionary: SpellingDictionary,
config: SuggestionConfig,
) -> Self
pub fn with_config( dictionary: SpellingDictionary, config: SuggestionConfig, ) -> Self
Create a new suggestion engine with custom configuration.
Sourcepub fn set_config(&mut self, config: SuggestionConfig)
pub fn set_config(&mut self, config: SuggestionConfig)
Update the configuration.
Sourcepub fn suggest(&self, word: &str) -> Vec<Suggestion>
pub fn suggest(&self, word: &str) -> Vec<Suggestion>
Get suggestions for a potentially misspelled word.
Sourcepub fn dictionary_stats(&self) -> (usize, u64)
pub fn dictionary_stats(&self) -> (usize, u64)
Get dictionary statistics.
Sourcepub fn is_correct(&self, word: &str) -> bool
pub fn is_correct(&self, word: &str) -> bool
Check if a word exists in the dictionary.
Sourcepub fn add_word(&mut self, word: &str, frequency: u32)
pub fn add_word(&mut self, word: &str, frequency: u32)
Add a word to the dictionary with the given frequency.
This allows the suggestion engine to learn new words dynamically.
Sourcepub fn word_frequency(&self, word: &str) -> u32
pub fn word_frequency(&self, word: &str) -> u32
Get the frequency of a word in the dictionary.