pub struct AnalyzerDefinition {
pub char_filters: Vec<CharFilterConfig>,
pub tokenizer: TokenizerConfig,
pub token_filters: Vec<TokenFilterConfig>,
}Expand description
A custom analyzer definition composed of a tokenizer and optional char/token filter chains.
Fields
char_filters- Applied to raw text before tokenization.tokenizer- Splits text into tokens.token_filters- Applied sequentially to the token stream.
Fields
char_filters: Vec<CharFilterConfig>Char filters applied to raw text before tokenization.
tokenizer: TokenizerConfigThe tokenizer that splits text into tokens.
token_filters: Vec<TokenFilterConfig>Token filters applied to the token stream after tokenization.