VectorSearchRequestBuilder

Struct VectorSearchRequestBuilder 

pub struct VectorSearchRequestBuilder { /* private fields */ }
Builder for constructing VectorSearchRequest.

Example

use laurus::vector::query::VectorSearchRequestBuilder;

let request = VectorSearchRequestBuilder::new()
    .add_vector("content", vec![0.1, 0.2, 0.3])
    .limit(5)
    .build();

Implementations

Source

impl VectorSearchRequestBuilder

pub fn new() -> Self

Create a new VectorSearchRequestBuilder.

pub fn add_vector(self, field: impl Into<String>, vector: Vec<f32>) -> Self

Add a raw query vector for a specific field.

pub fn add_vector_with_weight( self, field: impl Into<String>, vector: Vec<f32>, weight: f32, ) -> Self

Add a raw query vector with explicit weight for a specific field.

pub fn add_payload(self, field: impl Into<String>, payload: DataValue) -> Self

Add a payload to be embedded.

This is the unified method for all modalities (text, image, video, etc.). The bytes will be processed by the configured embedder.

Arguments
  • field - The target field name
  • payload - The payload to add

This is the low-level method used by add_text, add_image, etc.

pub fn add_bytes( self, field: impl Into<String>, bytes: impl Into<Vec<u8>>, mime: Option<impl Into<String>>, ) -> Self

Add a raw bytes payload (e.g. image bytes).

pub fn add_text(self, field: impl Into<String>, text: impl Into<String>) -> Self

Add a text payload to be embedded.

pub fn fields(self, fields: Vec<String>) -> Self

Set the fields to search in.

pub fn field(self, field: impl Into<String>) -> Self

Add a field to search in.

This is a convenience method to add a single field.

pub fn limit(self, limit: usize) -> Self

Set the search limit.

pub fn score_mode(self, mode: VectorScoreMode) -> Self

Set the score mode.

pub fn overfetch(self, overfetch: f32) -> Self

Set the overfetch factor.

pub fn min_score(self, min_score: f32) -> Self

Set the minimum score threshold.

pub fn build(self) -> VectorSearchRequest

Build the VectorSearchRequest.

If any pre-embedded vectors were added via add_vector or add_vector_with_weight, the query will use VectorSearchQuery::Vectors. Otherwise, if payloads were added via add_payload, add_text, or add_bytes, the query will use VectorSearchQuery::Payloads.