pub struct DateTimeRangeQuery { /* private fields */ }Expand description
Specialized datetime range query for optimal performance.
Implementations
Sourceimpl DateTimeRangeQuery
impl DateTimeRangeQuery
Sourcepub fn new<S: Into<String>>(
field: S,
lower: Option<DateTime<Utc>>,
upper: Option<DateTime<Utc>>,
lower_inclusive: bool,
upper_inclusive: bool,
) -> Self
pub fn new<S: Into<String>>( field: S, lower: Option<DateTime<Utc>>, upper: Option<DateTime<Utc>>, lower_inclusive: bool, upper_inclusive: bool, ) -> Self
Create a new datetime range query.
Sourcepub fn between<S: Into<String>>(
field: S,
start: DateTime<Utc>,
end: DateTime<Utc>,
) -> Self
pub fn between<S: Into<String>>( field: S, start: DateTime<Utc>, end: DateTime<Utc>, ) -> Self
Create a datetime range with both bounds inclusive.
Sourcepub fn after<S: Into<String>>(field: S, datetime: DateTime<Utc>) -> Self
pub fn after<S: Into<String>>(field: S, datetime: DateTime<Utc>) -> Self
Create a query for dates after the given datetime.
Sourcepub fn on_or_after<S: Into<String>>(field: S, datetime: DateTime<Utc>) -> Self
pub fn on_or_after<S: Into<String>>(field: S, datetime: DateTime<Utc>) -> Self
Create a query for dates on or after the given datetime.
Sourcepub fn before<S: Into<String>>(field: S, datetime: DateTime<Utc>) -> Self
pub fn before<S: Into<String>>(field: S, datetime: DateTime<Utc>) -> Self
Create a query for dates before the given datetime.
Sourcepub fn on_or_before<S: Into<String>>(field: S, datetime: DateTime<Utc>) -> Self
pub fn on_or_before<S: Into<String>>(field: S, datetime: DateTime<Utc>) -> Self
Create a query for dates on or before the given datetime.
Sourcepub fn with_boost(self, boost: f32) -> Self
pub fn with_boost(self, boost: f32) -> Self
Set the boost factor for this query.
Sourcepub fn contains_timestamp(&self, timestamp: i64) -> bool
pub fn contains_timestamp(&self, timestamp: i64) -> bool
Check if a timestamp falls within the range.
Sourcepub fn contains_datetime(&self, datetime: &DateTime<Utc>) -> bool
pub fn contains_datetime(&self, datetime: &DateTime<Utc>) -> bool
Check if a datetime falls within the range.