pub struct StorageFactory;Expand description
A factory for creating storage instances.
This factory creates appropriate storage implementations based on the provided configuration. It follows the same pattern as LexicalIndexFactory.
Implementations
Sourceimpl StorageFactory
impl StorageFactory
Sourcepub fn create(config: StorageConfig) -> Result<Arc<dyn Storage>>
pub fn create(config: StorageConfig) -> Result<Arc<dyn Storage>>
Create a new storage instance with the given configuration.
Arguments
config- Storage configuration (enum containing type-specific settings including path for file storage)
Returns
A boxed storage implementation based on the configured storage type.
Example
use laurus::storage::{StorageFactory, StorageConfig};
use laurus::storage::file::FileStorageConfig;
use laurus::storage::memory::MemoryStorageConfig;
// Create memory storage
let config = StorageConfig::Memory(MemoryStorageConfig::default());
let storage = StorageFactory::create(config)?;
// Create file storage
let file_config = FileStorageConfig::new("/tmp/index");
let config = StorageConfig::File(file_config);
let storage = StorageFactory::create(config)?;Auto Trait Implementations
impl Freeze for StorageFactory
impl RefUnwindSafe for StorageFactory
impl Send for StorageFactory
impl Sync for StorageFactory
impl Unpin for StorageFactory
impl UnsafeUnpin for StorageFactory
impl UnwindSafe for StorageFactory